#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-megaparsec
version:              2.2.1
visibility:           public
id:                   hspec-megaparsec-2.2.1-GvGlZ9uUSd6GkOrn6uLqvH
key:                  hspec-megaparsec-2.2.1-GvGlZ9uUSd6GkOrn6uLqvH
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/hspec-megaparsec
synopsis:             Utility functions for testing Megaparsec parsers with Hspec
description:
    Utility functions for testing Megaparsec parsers with Hspec.

category:             Testing, Parsing
abi:                  fa5f04f8130a5498a0f622a280306902
exposed:              True
exposed-modules:      Test.Hspec.Megaparsec
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hspec-megaparsec-2.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hspec-megaparsec-2.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hspec-megaparsec-2.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-megaparsec
hs-libraries:         HShspec-megaparsec-2.2.1-GvGlZ9uUSd6GkOrn6uLqvH
depends:
    base-4.18.2.1 hspec-expectations-0.8.4-JRz47SURfXgGxfIuVeuxEa
    megaparsec-9.7.0-FdYBNaij1jTCuKFJzO2IAw

haddock-interfaces:
    /usr/share/doc/haskell-hspec-megaparsec/html/hspec-megaparsec.haddock

haddock-html:         /usr/share/doc/haskell-hspec-megaparsec/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

